@@ -309,8 +309,10 @@ namespace QuantLib {
             return false;
 
         // Special closings
-        if (// Hurricane Sandy
-            (y == 2012 && m == October && (d == 29 || d == 30))
+        if (// President Bush's Funeral
+            (y == 2018 && m == December && d == 5)
+            // Hurricane Sandy
+            || (y == 2012 && m == October && (d == 29 || d == 30))
             // President Ford's funeral
             || (y == 2007 && m == January && d == 2)
             // President Reagan's funeral
